@@ -60,7 +60,7 @@ class cscRoot (object):
         if issubclass(self.__class__.mro()[-2], ( list, dict )):
             super(cscRoot, self).__init__(*args)
 
-__version__ = '1.1.5'
+__version__ = '1.2.1'
 """The version of PyXB"""
 
 __url__ = 'http://pyxb.sourceforge.net'
@@ -173,7 +173,147 @@ PyXB methods.
 Applies only at compilation time; dynamic changes are ignored.
 """
 
+class ValidationConfig (object):
+    """Class holding configuration related to validation.
+
+    L{pyxb.GlobalValidationConfig} is available to influence validation in all
+    contexts.  Each binding class has a reference to an instance of this
+    class, which can be inspected using
+    L{pyxb.binding.basis._TypeBinding_mixin._GetValidationConfig} and changed
+    using L{pyxb.binding.basis._TypeBinding_mixin._SetValidationConfig}.  Each
+    binding instance has a reference inherited from its class which can be
+    inspected using L{pyxb.binding.basis._TypeBinding_mixin._validationConfig}
+    and changed using
+    L{pyxb.binding.basis._TypeBinding_mixin._setValidationConfig}.
+
+    This allows fine control on a per class and per-instance basis.
+
+    L{forBinding} replaces L{RequireValidWhenParsing}.
+
+    L{forDocument} replaces L{RequireValidWhenGenerating}.
+
+    L{contentInfluencesGeneration}, L{orphanElementInContent}, and
+    L{invalidElementInContent} control how
+    L{pyxb.binding.basis.complexTypeDefinition.orderedContent} affects
+    generated documents.
+    """
+
+    __forBinding = True
+    def _getForBinding (self):
+        """C{True} iff validation should be performed when manipulating a
+        binding instance.
+
+        This includes parsing a document or DOM tree, using a binding instance
+        class constructor, or assigning to an element or attribute field of a
+        binding instance."""
+        return self.__forBinding
+    def _setForBinding (self, value):
+        """Configure whether validation should be performed when manipulating
+        a binding instance."""
+        if not isinstance(value, bool):
+            raise TypeError(value)
+        self.__forBinding = value
+        return value
+    forBinding = property(_getForBinding)
+
+    __forDocument = True
+    def _getForDocument (self):
+        """C{True} iff validation should be performed when creating a document
+        from a binding instance.
+
+        This applies at invocation of
+        L{toDOM()<pyxb.binding._TypeBinding_mixin.toDOM>}.
+        L{toxml()<pyxb.binding._TypeBinding_mixin.toDOM>} invokes C{toDOM()}."""
+        return self.__forDocument
+    def _setForDocument (self, value):
+        """Configure whether validation should be performed when generating
+        a document from a binding instance."""
+        if not isinstance(value, bool):
+            raise TypeError(value)
+        self.__forDocument = value
+        return value
+    forDocument = property(_getForDocument)
+
+    ALWAYS = -1
+    """Always do it."""
+
+    NEVER = 0
+    """Never do it."""
+
+    IGNORE_ONCE = 1
+    """If an error occurs ignore it and continue with the next one.  (E.g., if
+    an element in a content list fails skip it and continue with the next
+    element in the list.)"""
+    
+    GIVE_UP = 2
+    """If an error occurs ignore it and stop using whatever provided the cause
+    of the error.  (E.g., if an element in a content list fails stop
+    processing the content list and execute as though it was absent)."""
+
+    RAISE_EXCEPTION = 3
+    """If an error occurs, raise an exception."""
+
+    MIXED_ONLY = 4
+    """Only when content type is mixed."""
+
+    __contentInfluencesGeneration = MIXED_ONLY
+    def __getContentInfluencesGeneration (self):
+        """Determine whether complex type content influences element order in
+        document generation.
+
+        The value is one of L{ALWAYS}, L{NEVER}, L{MIXED_ONLY} (default)."""
+        return self.__contentInfluencesGeneration
+    def _setContentInfluencesGeneration (self, value):
+        """Set the value of L{contentInfluencesGeneration}."""
+        if not (value in ( self.ALWAYS, self.NEVER, self.MIXED_ONLY )):
+            raise ValueError(value)
+        self.__contentInfluencesGeneration = value
+    contentInfluencesGeneration = property(__getContentInfluencesGeneration)
+
+    __orphanElementInContent = IGNORE_ONCE
+    def __getOrphanElementInContent (self):
+        """How to handle unrecognized elements in content lists.
+
+        This is used when consulting a complex type instance content list to
+        influence the generation of documents from a binding instance.
+
+        The value is one of L{IGNORE_ONCE} (default), L{GIVE_UP},
+        L{RAISE_EXCEPTION}."""
+        return self.__orphanElementInContent
+    def _setOrphanElementInContent (self, value):
+        """Set the value of L{orphanElementInContent}."""
+        if not (value in ( self.IGNORE_ONCE, self.GIVE_UP, self.RAISE_EXCEPTION )):
+            raise ValueError(value)
+        self.__orphanElementInContent = value
+    orphanElementInContent = property(__getOrphanElementInContent)
+    
+    __invalidElementInContent = IGNORE_ONCE
+    def __getInvalidElementInContent (self):
+        """How to handle invalid elements in content lists.
+
+        The value is one of L{IGNORE_ONCE} (default), L{GIVE_UP},
+        L{RAISE_EXCEPTION}."""
+        return self.__invalidElementInContent
+    def _setInvalidElementInContent (self, value):
+        """Set the value of L{invalidElementInContent}."""
+        if not (value in ( self.IGNORE_ONCE, self.GIVE_UP, self.RAISE_EXCEPTION )):
+            raise ValueError(value)
+        self.__invalidElementInContent = value
+    invalidElementInContent = property(__getInvalidElementInContent)
+
+    def copy (self):
+        """Make a copy of this instance.
+
+        Use this to get a starting point when you need to customize validation
+        on a per-instance/per-class basis."""
+        import copy
+        return copy.copy(self)
+
+GlobalValidationConfig = ValidationConfig()
+
 _GenerationRequiresValid = True
+"""Legacy flag; prefer L{forDocument<ValidationConfig.forDocument>} in L{GlobalValidationConfig}."""
+
 def RequireValidWhenGenerating (value=None):
     """Query or set a flag that controls validation checking in XML generation.
 
@@ -192,15 +332,14 @@ def RequireValidWhenGenerating (value=None):
 
     @return: C{True} iff attempts to generate XML for a binding that does not
     validate should raise an exception.  """
-    global _GenerationRequiresValid
     if value is None:
-        return _GenerationRequiresValid
-    if not isinstance(value, bool):
-        raise TypeError(value)
-    _GenerationRequiresValid = value
-    return _GenerationRequiresValid
+        return GlobalValidationConfig.forDocument
+    global _GenerationRequiresValid
+    _GenerationRequiresValid = GlobalValidationConfig._setForDocument(value)
+    return value
 
 _ParsingRequiresValid = True
+"""Legacy flag; prefer L{forBinding<ValidationConfig.forBinding>} in L{GlobalValidationConfig}."""
 def RequireValidWhenParsing (value=None):
     """Query or set a flag that controls validation checking in XML parsing.
 
@@ -218,12 +357,10 @@ def RequireValidWhenParsing (value=None):
 
     @return: C{True} iff attempts to generate bindings for a document that
     does not validate should raise an exception."""
-    global _ParsingRequiresValid
     if value is None:
-        return _ParsingRequiresValid
-    if not isinstance(value, bool):
-        raise TypeError(value)
-    _ParsingRequiresValid = value
+        return GlobalValidationConfig.forBinding
+    global _ParsingRequiresValid
+    _ParsingRequiresValid = GlobalValidationConfig._setForBinding(value)
     return _ParsingRequiresValid
 
 _PreserveInputTimeZone = False
