@@ -118,7 +118,7 @@ class boolean (basis.simpleTypeDefinition, types.IntType):
                 else:
                     iv = False
                 return super(boolean, cls).__new__(cls, iv, *args, **kw)
-            raise BadTypeValueError('[xsd:boolean] Initializer "%s" not valid for type' % (value,))
+            raise SimpleTypeValueError(cls, value)
         return super(boolean, cls).__new__(cls, *args, **kw)
 
 _PrimitiveDatatypes.append(boolean)
@@ -198,22 +198,22 @@ class duration (basis.simpleTypeDefinition, datetime.timedelta):
     def __new__ (cls, *args, **kw):
         args = cls._ConvertArguments(args, kw)
         if 0 == len(args):
-            raise BadTypeValueError('[xsd:duration] Type requires an initializer')
+            raise SimpleTypeValueError(cls, args)
         text = args[0]
         have_kw_update = False
         if isinstance(text, (str, unicode)):
             match = cls.__Lexical_re.match(text)
             if match is None:
-                raise BadTypeValueError('Value "%s" not in %s lexical space' % (text, cls._ExpandedName)) 
+                raise SimpleTypeValueError(cls, text)
             match_map = match.groupdict()
-            if 'T' == match_map.get('Time', None):
+            if 'T' == match_map.get('Time'):
                 # Can't have T without additional time information
-                raise BadTypeValueError('Value "%s" not in %s lexical space' % (text, cls._ExpandedName)) 
+                raise SimpleTypeValueError(cls, text)
 
-            negative_duration = ('-' == match_map.get('neg', None))
+            negative_duration = ('-' == match_map.get('neg'))
 
             fractional_seconds = 0.0
-            if match_map.get('fracsec', None) is not None:
+            if match_map.get('fracsec') is not None:
                 fractional_seconds = types.FloatType('0%s' % (match_map['fracsec'],))
                 usec = types.IntType(1000000 * fractional_seconds)
                 if negative_duration:
@@ -253,7 +253,7 @@ class duration (basis.simpleTypeDefinition, datetime.timedelta):
             data['minutes'] = 0
             data['hours'] = 0
         else:
-            raise BadTypeValueError('[xsd:duration] Initializer "%s" type %s not valid for type' % (text, type(text)))
+            raise SimpleTypeValueError(cls, text)
         if not have_kw_update:
             rem_time = data['seconds']
             if (0 != (rem_time % 1)):
@@ -352,20 +352,20 @@ class _PyXBDateTime_base (basis.simpleTypeDefinition):
             cls.__LexicalREMap[cls] = lexical_re
         match = lexical_re.match(text)
         if match is None:
-            raise BadTypeValueError('Value "%s" not in %s lexical space' % (text, cls._ExpandedName)) 
+            raise SimpleTypeValueError(cls, text)
         match_map = match.groupdict()
         kw = { }
         for (k, v) in match_map.iteritems():
             if (k in cls.__LexicalIntegerFields) and (v is not None):
                 kw[k] = types.IntType(v)
-        if '-' == match_map.get('negYear', None):
+        if '-' == match_map.get('negYear'):
             kw['year'] = - kw['year']
-        if match_map.get('fracsec', None) is not None:
+        if match_map.get('fracsec') is not None:
             kw['microsecond'] = types.IntType(round(1000000 * types.FloatType('0%s' % (match_map['fracsec'],))))
         else:
             # Discard any bogosity passed in by the caller
             kw.pop('microsecond', None)
-        if match_map.get('tzinfo', None) is not None:
+        if match_map.get('tzinfo') is not None:
             kw['tzinfo'] = pyxb.utils.utility.UTCOffsetTimeZone(match_map['tzinfo'])
         else:
             kw.pop('tzinfo', None)
@@ -463,7 +463,7 @@ class dateTime (_PyXBDateTime_base, datetime.datetime):
             elif isinstance(value, (types.IntType, types.LongType)):
                 raise TypeError('function takes at least 3 arguments (%d given)' % (len(args),))
             else:
-                raise BadTypeValueError('Unexpected type %s in %s' % (type(value), cls._ExpandedName))
+                raise SimpleTypeValueError(cls, value)
         elif 3 <= len(args):
             for fi in range(len(cls.__CtorFields)):
                 fn = cls.__CtorFields[fi]
@@ -540,7 +540,7 @@ class time (_PyXBDateTime_base, datetime.time):
                         ctor_kw[fn] = kw[fn]
                     kw.pop(fn, None)
             else:
-                raise BadTypeValueError('Unexpected type %s' % (type(value),))
+                raise SimpleTypeValueError(cls, value)
 
         cls._AdjustForTimezone(ctor_kw)
         kw.update(ctor_kw)
@@ -751,7 +751,7 @@ class hexBinary (basis.simpleTypeDefinition, types.StringType):
             try:
                 args = (binascii.unhexlify(args[0]),) + args[1:]
             except TypeError:
-                raise BadTypeValueError('%s is not a valid hexBinary string' % (cls.__class__.__name__,))
+                raise SimpleTypeValueError(cls, args[0])
         return args
 
     @classmethod
@@ -791,11 +791,11 @@ class base64Binary (basis.simpleTypeDefinition, types.StringType):
             xmls = args[0]
             try:
                 args = (base64.standard_b64decode(xmls),) + args[1:]
-            except TypeError, e:
-                raise BadTypeValueError('%s is not a valid base64Binary string: %s' % (cls.__class__.__name__, str(e)))
+            except TypeError as e:
+                raise SimpleTypeValueError(cls, xmls)
             # This is what it costs to try to be a validating processor.
             if cls.__Lexical_re.match(xmls) is None:
-                raise BadTypeValueError('%s is not a valid base64Binary string: XML strict failed' % (cls.__class__.__name__,))
+                raise SimpleTypeValueError(cls, xmls)
         return args
 
     @classmethod
@@ -861,14 +861,14 @@ class QName (basis.simpleTypeDefinition, unicode):
     @classmethod
     def _XsdConstraintsPreCheck_vb (cls, value):
         if not isinstance(value, types.StringTypes):
-            raise BadTypeValueError('%s value must be a string' % (cls.__name__,))
+            raise SimpleTypeValueError(cls, value)
         if 0 <= value.find(':'):
             (prefix, local) = value.split(':', 1)
             if (NCName._ValidRE.match(prefix) is None) or (NCName._ValidRE.match(local) is None):
-                raise BadTypeValueError('%s lexical/value space violation for "%s"' % (cls.__name__, value))
+                raise SimpleTypeValueError(cls, value)
         else:
             if NCName._ValidRE.match(value) is None:
-                raise BadTypeValueError('%s lexical/value space violation for "%s"' % (cls.__name__, value))
+                raise SimpleTypeValueError(cls, value)
         super_fn = getattr(super(QName, cls), '_XsdConstraintsPreCheck_vb', lambda *a,**kw: True)
         return super_fn(value)
 
@@ -916,17 +916,17 @@ class normalizedString (string):
     def __ValidateString (cls, value):
         # This regular expression doesn't work.  Don't know why.
         #if cls.__BadChars.match(value) is not None:
-        #    raise BadTypeValueError('CR/NL/TAB characters illegal in %s' % (cls.__name__,))
+        #    raise SimpleTypeValueError('CR/NL/TAB characters illegal in %s' % (cls.__name__,))
         if (0 <= value.find("\n")) or (0 <= value.find("\r")) or (0 <= value.find("\t")):
-            raise BadTypeValueError('CR/NL/TAB characters illegal in %s' % (cls.__name__,))
+            raise SimpleTypeValueError(cls, value)
         if cls._ValidRE is not None:
             match_object = cls._ValidRE.match(value)
             if match_object is None:
-                raise BadTypeValueError('%s pattern constraint violation for "%s"' % (cls.__name__, value))
+                raise SimpleTypeValueError(cls, value)
         if cls._InvalidRE is not None:
             match_object = cls._InvalidRE.match(value)
             if not (match_object is None):
-                raise BadTypeValueError('%s pattern constraint violation for "%s"' % (cls.__name__, value))
+                raise SimpleTypeValueError(cls, value)
         return True
 
     @classmethod
@@ -948,9 +948,9 @@ class normalizedString (string):
     @classmethod
     def _XsdConstraintsPreCheck_vb (cls, value):
         if not isinstance(value, types.StringTypes):
-            raise BadTypeValueError('%s value must be a string' % (cls.__name__,))
+            raise SimpleTypeValueError(cls, value)
         if not cls._ValidateString_va(value):
-            raise BadTypeValueError('%s lexical/value space violation for "%s"' % (cls.__name__, value))
+            raise SimpleTypeValueError(cls, value)
         super_fn = getattr(super(normalizedString, cls), '_XsdConstraintsPreCheck_vb', lambda *a,**kw: True)
         return super_fn(value)
 
@@ -971,12 +971,10 @@ class token (normalizedString):
         super_fn = getattr(super(token, cls), '_ValidateString_va', lambda *a,**kw: True)
         if not super_fn(value):
             return False
-        if value.startswith(" "):
-            raise BadTypeValueError('Leading spaces in token')
-        if value.endswith(" "):
-            raise BadTypeValueError('Trailing spaces in token')
-        if 0 <= value.find('  '):
-            raise BadTypeValueError('Multiple internal spaces in token')
+        if value.startswith(" ") \
+           or value.endswith(" ") \
+           or (0 <= value.find('  ')):
+            raise SimpleTypeValueError(cls, value)
         return True
 _DerivedDatatypes.append(token)
 
@@ -1139,16 +1137,35 @@ import content
 class anyType (basis.complexTypeDefinition):
     """XMLSchema datatype U{anyType<http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/#key-urType>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('anyType')
+    _DefinitionLocation = pyxb.utils.utility.Location('http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/#key-urType', 1, 1)
     _ContentTypeTag = basis.complexTypeDefinition._CT_MIXED
     _Abstract = False
     _HasWildcardElement = True
     _AttributeWildcard = content.Wildcard(namespace_constraint=content.Wildcard.NC_any, process_contents=content.Wildcard.PC_lax)
 
-    # Generate from tests/schemas/anyType.xsd
-    __Wildcard = content.Wildcard(process_contents=content.Wildcard.PC_lax, namespace_constraint=content.Wildcard.NC_any)
-    __Inner = content.GroupSequence(content.ParticleModel(__Wildcard, min_occurs=0, max_occurs=None))
-    _ContentModel = content.ParticleModel(__Inner, min_occurs=1, max_occurs=1)
+def _BuildAutomaton ():
+    # Remove this helper function from the namespace after it's invoked
+    global _BuildAutomaton
+    del _BuildAutomaton
+    import pyxb.utils.fac as fac
 
+    counters = set()
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/#key-urType', 1, 1))
+    counters.add(cc_0)
+    states = set()
+    final_update = set()
+    final_update.add(fac.UpdateInstruction(cc_0, False))
+    symbol = content.WildcardUse(content.Wildcard(process_contents=content.Wildcard.PC_lax, namespace_constraint=content.Wildcard.NC_any), None)
+    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
+    states.add(st_0)
+    transitions = set()
+    transitions.add(fac.Transition(st_0, [
+        fac.UpdateInstruction(cc_0, True) ]))
+    st_0._set_transitionSet(transitions)
+    return fac.Automaton(states, counters, True, containing_state=None)
+anyType._Automaton = _BuildAutomaton()
+
+    
 # anyType._IsUrType() is True; foo._IsUrType() for descendents of it
 # should be false.
 anyType._IsUrType = classmethod(lambda _c: _c == anyType)
