@@ -104,7 +104,8 @@ class _SAXElementState (pyxb.utils.saxutils.SAXElementState):
 
     # Create the binding instance for this element.
     def __constructElement (self, new_object_factory, attrs, content=None):
-        kw = { '_from_xml' : True }
+        kw = { '_from_xml' : True,
+               '_location' : self.location() }
 
         # Note whether the node is marked nil
         if attrs.has_key(self.__XSINilTuple):
@@ -129,6 +130,8 @@ class _SAXElementState (pyxb.utils.saxutils.SAXElementState):
             # Ignore xmlns and xsi attributes; we've already handled those
             if attr_en.namespace() in ( pyxb.namespace.XMLNamespaces, XSI ):
                 continue
+            # The binding instance may be a simple type that does not support
+            # attributes; the following raises an exception in that case.
             self.__bindingInstance._setAttribute(attr_en, attrs.getValue(attr_name))
 
         return self.__bindingInstance
@@ -159,11 +162,11 @@ class _SAXElementState (pyxb.utils.saxutils.SAXElementState):
         """Actions upon leaving an element that is part of a DOM subtree."""
         ns_ctx = self.namespaceContext()
         element = pyxb.utils.saxdom.Element(namespace_context=ns_ctx, expanded_name=self.expandedName(), attributes=self.__attributes, location=self.location())
-        for ( content, element_use, maybe_element ) in self.content():
-            if isinstance(content, xml.dom.Node):
-                element.appendChild(content)
+        for info in self.content():
+            if isinstance(info.item, xml.dom.Node):
+                element.appendChild(info.item)
             else:
-                element.appendChild(pyxb.utils.saxdom.Text(content, namespace_context=ns_ctx))
+                element.appendChild(pyxb.utils.saxdom.Text(info.item, namespace_context=ns_ctx))
         self.__domDepth -= 1
         if 0 == self.__domDepth:
             self.__domDocument.appendChild(element)
@@ -171,10 +174,10 @@ class _SAXElementState (pyxb.utils.saxutils.SAXElementState):
             self.__domDepth = None
             self.__domDocument = None
         parent_state = self.parentState()
-        parent_state.addElementContent(element, None)
+        parent_state.addElementContent(self.location(), element, None)
         return element
 
-    def startBindingElement (self, type_class, new_object_factory, element_use, attrs):
+    def startBindingElement (self, type_class, new_object_factory, element_decl, attrs):
         """Actions upon entering an element that will produce a binding instance.
 
         The element use is recorded.  If the type is a subclass of
@@ -187,14 +190,14 @@ class _SAXElementState (pyxb.utils.saxutils.SAXElementState):
         @param type_class: The Python type of the binding instance
         @type type_class: subclass of L{basis._TypeBinding_mixin}
         @param new_object_factory: A callable object that creates an instance of the C{type_class}
-        @param element_use: The element use with which the binding instance is associated.  Will be C{None} for top-level elements
-        @type element_use: L{basis.element}
+        @param element_decl: The element use with which the binding instance is associated.  Will be C{None} for top-level elements
+        @type element_decl: L{basis.element}
         @param attrs: The XML attributes associated with the element
         @type attrs: C{xml.sax.xmlreader.Attributes}
         @return: The generated binding instance, or C{None} if creation is delayed
         """
         self.__delayedConstructor = None
-        self.__elementUse = element_use
+        self.__elementDecl = element_decl
         self.__attributes = attrs
         if type_class._IsSimpleTypeContent():
             self.__delayedConstructor = new_object_factory
@@ -210,25 +213,26 @@ class _SAXElementState (pyxb.utils.saxutils.SAXElementState):
         """
         if self.__delayedConstructor is not None:
             args = []
-            for (content, element_use, maybe_element) in self.__content:
-                assert not maybe_element
-                assert element_use is None
-                assert isinstance(content, basestring)
-                args.append(content)
+            for info in self.content():
+                assert not info.maybe_element
+                assert info.element_decl is None
+                assert isinstance(info.item, basestring)
+                args.append(info.item)
             assert 1 >= len(args), 'Unexpected STD content %s' % (args,)
             self.__constructElement(self.__delayedConstructor, self.__attributes, args)
         else:
-            for (content, element_use, maybe_element) in self.__content:
-                self.__bindingInstance.append(content, element_use, maybe_element, require_validation=pyxb._ParsingRequiresValid)
+            for info in self.content():
+                self.__bindingInstance.append(info.item,
+                                              _element_decl=info.element_decl,
+                                              _maybe_element=info.maybe_element,
+                                              _location=info.location)
         parent_state = self.parentState()
         if parent_state is not None:
-            parent_state.addElementContent(self.__bindingInstance, self.__elementUse)
+            parent_state.addElementContent(self.location(), self.__bindingInstance, self.__elementDecl)
         # As CreateFromDOM does, validate the resulting element
         if self.__bindingInstance._element() is None:
             self.__bindingInstance._setElement(self.__elementBinding)
-        if pyxb._ParsingRequiresValid:
-            self.__bindingInstance.validateBinding()
-        return self.__bindingInstance
+        return self.__bindingInstance._postDOMValidate()
 
 class PyXBSAXHandler (pyxb.utils.saxutils.BaseSAXHandler):
     """A SAX handler class which generates a binding instance for a document
@@ -262,12 +266,13 @@ class PyXBSAXHandler (pyxb.utils.saxutils.BaseSAXHandler):
         @return: An instance of L{basis._TypeBinding_mixin} (most usually a
         L{basis.complexTypeDefinition}.
 
-        @raise pyxb.UnrecognizedElementError: No binding could be found to
+        @raise pyxb.[UnrecognizedDOMRootNodeError: No binding could be found to
         match the top-level element in the document."""
         if not isinstance(self.__rootObject, basis._TypeBinding_mixin):
             # Happens if the top-level element got processed as a DOM instance.
-            raise pyxb.UnrecognizedElementError(dom_node=self.__rootObject)
-        return self.__rootObject
+            assert isinstance(self.__rootObject, xml.dom.Node)
+            raise pyxb.UnrecognizedDOMRootNodeError(self.__rootObject)
+        return self.__rootObject._postDOMValidate()
     __rootObject = None
 
     def reset (self):
@@ -302,18 +307,18 @@ class PyXBSAXHandler (pyxb.utils.saxutils.BaseSAXHandler):
         # Resolve the element within the appropriate context.  Note
         # that global elements have no use, only the binding.
         if parent_state.enclosingCTD() is not None:
-            (element_binding, element_use) = parent_state.enclosingCTD()._ElementBindingUseForName(name_en)
+            (element_binding, element_decl) = parent_state.enclosingCTD()._ElementBindingDeclForName(name_en)
         else:
-            element_use = None
+            element_decl = None
             element_binding = name_en.elementBinding()
         this_state.setElementBinding(element_binding)
 
         # Non-root elements should have an element use, from which we can
         # extract the binding if we couldn't find one elsewhere.  (Keep any
         # current binding, since it may be a member of a substitution group.)
-        if (element_use is not None) and (element_binding is None):
+        if (element_decl is not None) and (element_binding is None):
             assert self.__rootObject is not None
-            element_binding = element_use.elementBinding()
+            element_binding = element_decl.elementBinding()
             assert element_binding is not None
 
         # Start knowing nothing
@@ -351,7 +356,7 @@ class PyXBSAXHandler (pyxb.utils.saxutils.BaseSAXHandler):
 
         # Process the element start.  This may or may not return a
         # binding object.
-        binding_object = this_state.startBindingElement(type_class, new_object_factory, element_use, attrs)
+        binding_object = this_state.startBindingElement(type_class, new_object_factory, element_decl, attrs)
 
         # If the top-level element has complex content, this sets the
         # root object.  If it has simple content, see endElementNS.
@@ -378,7 +383,11 @@ class PyXBSAXHandler (pyxb.utils.saxutils.BaseSAXHandler):
         # created on start, and the root object has been assigned.  If
         # it has simple content, then there are no internal elements
         # that could slip in and set this before we get to it here.
-        if self.__rootObject is None:
+        #
+        # Unless we're still in DOM mode, in which case this isn't really the
+        # root object.  Then the real root object will be the one that caused
+        # us to enter DOM mode.
+        if (self.__rootObject is None) and not this_state.inDOMMode():
             self.__rootObject = binding_object
 
 def make_parser (*args, **kw):
