@@ -1,7 +1,7 @@
 # ./pyxb/bundles/common/raw/xsd_hfp.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:c53ce1768a4a63294762e2dee968b656ae0d44d0
-# Generated 2012-11-01 15:13:30.156989 by PyXB version 1.1.5
+# Generated 2012-12-17 13:09:17.132772 by PyXB version 1.2.1
 # Namespace http://www.w3.org/2001/XMLSchema-hasFacetAndProperty
 
 import pyxb
@@ -13,7 +13,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9a760e28-2460-11e2-acbf-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:40e19b70-487d-11e2-85d6-c8600024e903')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -56,7 +56,7 @@ def CreateFromDOM (node, default_namespace=None):
     @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
     if default_namespace is None:
         default_namespace = Namespace.fallbackNamespace()
-    return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
+    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)
 
 
 # Atomic simple type: [anonymous]
@@ -68,7 +68,7 @@ class STD_ANON (pyxb.binding.datatypes.NMTOKEN, pyxb.binding.basis.enumeration_m
       """
 
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/common/schemas/xsd_hfp.xsd', 60, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 60, 4)
     _Documentation = u'\n       \n       \n      '
 STD_ANON._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON, enum_prefix=None)
 STD_ANON.length = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'length', tag=u'length')
@@ -96,7 +96,7 @@ class STD_ANON_ (pyxb.binding.datatypes.NMTOKEN, pyxb.binding.basis.enumeration_
       """
 
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/common/schemas/xsd_hfp.xsd', 117, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 117, 4)
     _Documentation = u'\n       \n       \n      '
 STD_ANON_._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_, enum_prefix=None)
 STD_ANON_.ordered = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'ordered', tag=u'ordered')
@@ -107,17 +107,22 @@ STD_ANON_._InitializeFacetMap(STD_ANON_._CF_enumeration)
 
 # Complex type [anonymous] with content type EMPTY
 class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
+    """
+   
+   
+   
+   """
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/common/schemas/xsd_hfp.xsd', 58, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 58, 2)
     # Base type is pyxb.binding.datatypes.anyType
     
     # Attribute name uses Python identifier name
     __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpwww_w3_org2001XMLSchema_hasFacetAndProperty_CTD_ANON_name', STD_ANON, required=True)
-    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/common/schemas/xsd_hfp.xsd', 59, 3)
-    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/common/schemas/xsd_hfp.xsd', 59, 3)
+    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 59, 3)
+    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 59, 3)
     
     name = property(__name.value, __name.set, None, None)
 
@@ -133,25 +138,30 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
 
 # Complex type [anonymous] with content type EMPTY
 class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
+    """
+    
+    
+    
+   """
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/common/schemas/xsd_hfp.xsd', 115, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 115, 2)
     # Base type is pyxb.binding.datatypes.anyType
     
     # Attribute name uses Python identifier name
     __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpwww_w3_org2001XMLSchema_hasFacetAndProperty_CTD_ANON__name', STD_ANON_, required=True)
-    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/common/schemas/xsd_hfp.xsd', 116, 3)
-    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/common/schemas/xsd_hfp.xsd', 116, 3)
+    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 116, 3)
+    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 116, 3)
     
     name = property(__name.value, __name.set, None, None)
 
     
     # Attribute value uses Python identifier value_
     __value = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'value'), 'value_', '__httpwww_w3_org2001XMLSchema_hasFacetAndProperty_CTD_ANON__value', pyxb.binding.datatypes.normalizedString, required=True)
-    __value._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/common/schemas/xsd_hfp.xsd', 139, 3)
-    __value._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/common/schemas/xsd_hfp.xsd', 139, 3)
+    __value._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 139, 3)
+    __value._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 139, 3)
     
     value_ = property(__value.value, __value.set, None, None)
 
@@ -166,8 +176,8 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
 
 
 
-hasFacet = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'hasFacet'), CTD_ANON, documentation=u'\n   \n   \n   \n   ')
+hasFacet = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'hasFacet'), CTD_ANON, documentation=u'\n   \n   \n   \n   ', location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 35, 1))
 Namespace.addCategoryObject('elementBinding', hasFacet.name().localName(), hasFacet)
 
-hasProperty = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'hasProperty'), CTD_ANON_, documentation=u'\n    \n    \n    \n   ')
+hasProperty = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'hasProperty'), CTD_ANON_, documentation=u'\n    \n    \n    \n   ', location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/common/schemas/xsd_hfp.xsd', 97, 1))
 Namespace.addCategoryObject('elementBinding', hasProperty.name().localName(), hasProperty)
