@@ -1,7 +1,7 @@
 # ./pyxb/bundles/saml20/raw/x500.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:98344aaf7fd05f232dfec562262a7a9f0df31d06
-# Generated 2012-11-01 15:13:41.117906 by PyXB version 1.1.5
+# Generated 2012-12-17 13:09:32.958576 by PyXB version 1.2.1
 # Namespace urn:oasis:names:tc:SAML:2.0:profiles:attribute:X500
 
 import pyxb
@@ -13,7 +13,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:a0ff1fdc-2460-11e2-acda-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:4a511f78-487d-11e2-ba30-c8600024e903')
 
 # Import bindings for namespaces imported into schema
 
@@ -56,5 +56,5 @@ def CreateFromDOM (node, default_namespace=None):
     @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
     if default_namespace is None:
         default_namespace = Namespace.fallbackNamespace()
-    return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
+    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)
 
