@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/httpbind.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:700d4ca8e0588f8b897f9c60d123e08fa4d56b36
-# Generated 2012-11-01 15:13:34.188876 by PyXB version 1.1.5
+# Generated 2012-12-17 13:09:25.695580 by PyXB version 1.2.1
 # Namespace http://schemas.xmlsoap.org/wsdl/http/
 
 import pyxb
@@ -13,7 +13,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9cdbfb8c-2460-11e2-bf85-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:45fa1f24-487d-11e2-9ebf-c8600024e903')
 
 # Import bindings for namespaces imported into schema
 import pyxb.bundles.wssplat.wsdl11
@@ -57,93 +57,28 @@ def CreateFromDOM (node, default_namespace=None):
     @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
     if default_namespace is None:
         default_namespace = Namespace.fallbackNamespace()
-    return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
-
-
-# Complex type {http://schemas.xmlsoap.org/wsdl/http/}operationType with content type EMPTY
-class operationType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'operationType')
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 62, 4)
-    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
-    
-    # Attribute location uses Python identifier location
-    __location = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'location'), 'location', '__httpschemas_xmlsoap_orgwsdlhttp_operationType_location', pyxb.binding.datatypes.anyURI, required=True)
-    __location._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 66, 9)
-    __location._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 66, 9)
-    
-    location = property(__location.value, __location.set, None, None)
-
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-
-    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
-    _ElementMap.update({
-        
-    })
-    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
-    _AttributeMap.update({
-        __location.name() : __location
-    })
-Namespace.addCategoryObject('typeBinding', u'operationType', operationType)
-
-
-# Complex type [anonymous] with content type EMPTY
-class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 75, 8)
-    # Base type is pyxb.binding.datatypes.anyType
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-
-
-
-# Complex type [anonymous] with content type EMPTY
-class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 72, 8)
-    # Base type is pyxb.binding.datatypes.anyType
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-
+    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)
 
 
 # Complex type {http://schemas.xmlsoap.org/wsdl/http/}addressType with content type EMPTY
 class addressType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
+    """Complex type {http://schemas.xmlsoap.org/wsdl/http/}addressType with content type EMPTY"""
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'addressType')
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 42, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 42, 4)
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
     # Attribute location uses Python identifier location
     __location = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'location'), 'location', '__httpschemas_xmlsoap_orgwsdlhttp_addressType_location', pyxb.binding.datatypes.anyURI, required=True)
-    __location._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 46, 6)
-    __location._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 46, 6)
+    __location._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 46, 6)
+    __location._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 46, 6)
     
     location = property(__location.value, __location.set, None, None)
 
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
 
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _ElementMap.update({
@@ -158,22 +93,23 @@ Namespace.addCategoryObject('typeBinding', u'addressType', addressType)
 
 # Complex type {http://schemas.xmlsoap.org/wsdl/http/}bindingType with content type EMPTY
 class bindingType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
+    """Complex type {http://schemas.xmlsoap.org/wsdl/http/}bindingType with content type EMPTY"""
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'bindingType')
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 52, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 52, 4)
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
     # Attribute verb uses Python identifier verb
     __verb = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'verb'), 'verb', '__httpschemas_xmlsoap_orgwsdlhttp_bindingType_verb', pyxb.binding.datatypes.NMTOKEN, required=True)
-    __verb._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 56, 9)
-    __verb._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/httpbind.xsd', 56, 9)
+    __verb._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 56, 9)
+    __verb._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 56, 9)
     
     verb = property(__verb.value, __verb.set, None, None)
 
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
 
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _ElementMap.update({
@@ -186,17 +122,86 @@ class bindingType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
 Namespace.addCategoryObject('typeBinding', u'bindingType', bindingType)
 
 
-operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'operation'), operationType)
-Namespace.addCategoryObject('elementBinding', operation.name().localName(), operation)
+# Complex type {http://schemas.xmlsoap.org/wsdl/http/}operationType with content type EMPTY
+class operationType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
+    """Complex type {http://schemas.xmlsoap.org/wsdl/http/}operationType with content type EMPTY"""
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'operationType')
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 62, 4)
+    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
+    
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
+    # Attribute location uses Python identifier location
+    __location = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'location'), 'location', '__httpschemas_xmlsoap_orgwsdlhttp_operationType_location', pyxb.binding.datatypes.anyURI, required=True)
+    __location._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 66, 9)
+    __location._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 66, 9)
+    
+    location = property(__location.value, __location.set, None, None)
 
-urlReplacement = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'urlReplacement'), CTD_ANON)
-Namespace.addCategoryObject('elementBinding', urlReplacement.name().localName(), urlReplacement)
 
-urlEncoded = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'urlEncoded'), CTD_ANON_)
-Namespace.addCategoryObject('elementBinding', urlEncoded.name().localName(), urlEncoded)
+    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
+    _ElementMap.update({
+        
+    })
+    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
+    _AttributeMap.update({
+        __location.name() : __location
+    })
+Namespace.addCategoryObject('typeBinding', u'operationType', operationType)
 
-address = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'address'), addressType)
+
+# Complex type [anonymous] with content type EMPTY
+class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
+    """Complex type [anonymous] with content type EMPTY"""
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = None
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 72, 8)
+    # Base type is pyxb.binding.datatypes.anyType
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+
+
+
+# Complex type [anonymous] with content type EMPTY
+class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
+    """Complex type [anonymous] with content type EMPTY"""
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = None
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 75, 8)
+    # Base type is pyxb.binding.datatypes.anyType
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+
+
+
+address = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'address'), addressType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 40, 4))
 Namespace.addCategoryObject('elementBinding', address.name().localName(), address)
 
-binding = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'binding'), bindingType)
+binding = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'binding'), bindingType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 51, 4))
 Namespace.addCategoryObject('elementBinding', binding.name().localName(), binding)
+
+operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'operation'), operationType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 61, 4))
+Namespace.addCategoryObject('elementBinding', operation.name().localName(), operation)
+
+urlEncoded = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'urlEncoded'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 71, 4))
+Namespace.addCategoryObject('elementBinding', urlEncoded.name().localName(), urlEncoded)
+
+urlReplacement = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'urlReplacement'), CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/httpbind.xsd', 74, 4))
+Namespace.addCategoryObject('elementBinding', urlReplacement.name().localName(), urlReplacement)
