@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/mimebind.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:5404248094c8a480a41150c00669c3a55d100562
-# Generated 2012-11-01 15:13:34.381880 by PyXB version 1.1.5
+# Generated 2012-12-17 13:09:25.894256 by PyXB version 1.2.1
 # Namespace http://schemas.xmlsoap.org/wsdl/mime/
 
 import pyxb
@@ -13,11 +13,11 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9cf92856-2460-11e2-a190-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:4618516a-487d-11e2-9659-c8600024e903')
 
 # Import bindings for namespaces imported into schema
-import pyxb.binding.datatypes
 import pyxb.bundles.wssplat.wsdl11
+import pyxb.binding.datatypes
 
 Namespace = pyxb.namespace.NamespaceForURI(u'http://schemas.xmlsoap.org/wsdl/mime/', create_if_missing=True)
 Namespace.configureCategories(['typeBinding', 'elementBinding'])
@@ -57,49 +57,61 @@ def CreateFromDOM (node, default_namespace=None):
     @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
     if default_namespace is None:
         default_namespace = Namespace.fallbackNamespace()
-    return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
+    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)
 
 
-# Complex type {http://schemas.xmlsoap.org/wsdl/mime/}tPart with content type ELEMENT_ONLY
-class tPart (pyxb.binding.basis.complexTypeDefinition):
+# Complex type {http://schemas.xmlsoap.org/wsdl/mime/}contentType with content type EMPTY
+class contentType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
+    """Complex type {http://schemas.xmlsoap.org/wsdl/mime/}contentType with content type EMPTY"""
     _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tPart')
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 58, 7)
-    # Base type is pyxb.binding.datatypes.anyType
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'contentType')
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 39, 4)
+    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
-    # Attribute name uses Python identifier name
-    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpschemas_xmlsoap_orgwsdlmime_tPart_name', pyxb.binding.datatypes.NMTOKEN, required=True)
-    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 62, 9)
-    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 62, 9)
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
     
-    name = property(__name.value, __name.set, None, None)
+    # Attribute type uses Python identifier type
+    __type = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'type'), 'type', '__httpschemas_xmlsoap_orgwsdlmime_contentType_type', pyxb.binding.datatypes.string)
+    __type._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 43, 9)
+    __type._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 43, 9)
+    
+    type = property(__type.value, __type.set, None, None)
 
-    _HasWildcardElement = True
+    
+    # Attribute part uses Python identifier part
+    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlmime_contentType_part', pyxb.binding.datatypes.NMTOKEN)
+    __part._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 44, 9)
+    __part._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 44, 9)
+    
+    part = property(__part.value, __part.set, None, None)
 
-    _ElementMap = {
+
+    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
+    _ElementMap.update({
         
-    }
-    _AttributeMap = {
-        __name.name() : __name
-    }
-Namespace.addCategoryObject('typeBinding', u'tPart', tPart)
+    })
+    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
+    _AttributeMap.update({
+        __type.name() : __type,
+        __part.name() : __part
+    })
+Namespace.addCategoryObject('typeBinding', u'contentType', contentType)
 
 
 # Complex type {http://schemas.xmlsoap.org/wsdl/mime/}multipartRelatedType with content type ELEMENT_ONLY
 class multipartRelatedType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
+    """Complex type {http://schemas.xmlsoap.org/wsdl/mime/}multipartRelatedType with content type ELEMENT_ONLY"""
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'multipartRelatedType')
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 49, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 49, 4)
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
     # Element part uses Python identifier part
-    __part = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlmime_multipartRelatedType_part', True)
-    __part._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10)
-    __part._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 52, 3)
+    __part = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlmime_multipartRelatedType_part', True, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10), )
 
     
     part = property(__part.value, __part.set, None, None)
@@ -118,63 +130,53 @@ class multipartRelatedType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
 Namespace.addCategoryObject('typeBinding', u'multipartRelatedType', multipartRelatedType)
 
 
-# Complex type {http://schemas.xmlsoap.org/wsdl/mime/}contentType with content type EMPTY
-class contentType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
+# Complex type {http://schemas.xmlsoap.org/wsdl/mime/}tPart with content type ELEMENT_ONLY
+class tPart (pyxb.binding.basis.complexTypeDefinition):
+    """Complex type {http://schemas.xmlsoap.org/wsdl/mime/}tPart with content type ELEMENT_ONLY"""
     _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'contentType')
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 39, 4)
-    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tPart')
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 58, 7)
+    # Base type is pyxb.binding.datatypes.anyType
     
-    # Attribute part uses Python identifier part
-    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlmime_contentType_part', pyxb.binding.datatypes.NMTOKEN)
-    __part._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 44, 9)
-    __part._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 44, 9)
+    # Attribute name uses Python identifier name
+    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpschemas_xmlsoap_orgwsdlmime_tPart_name', pyxb.binding.datatypes.NMTOKEN, required=True)
+    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 62, 9)
+    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 62, 9)
     
-    part = property(__part.value, __part.set, None, None)
+    name = property(__name.value, __name.set, None, None)
 
-    
-    # Attribute type uses Python identifier type
-    __type = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'type'), 'type', '__httpschemas_xmlsoap_orgwsdlmime_contentType_type', pyxb.binding.datatypes.string)
-    __type._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 43, 9)
-    __type._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 43, 9)
-    
-    type = property(__type.value, __type.set, None, None)
+    _HasWildcardElement = True
 
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-
-    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
-    _ElementMap.update({
+    _ElementMap = {
         
-    })
-    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
-    _AttributeMap.update({
-        __part.name() : __part,
-        __type.name() : __type
-    })
-Namespace.addCategoryObject('typeBinding', u'contentType', contentType)
+    }
+    _AttributeMap = {
+        __name.name() : __name
+    }
+Namespace.addCategoryObject('typeBinding', u'tPart', tPart)
 
 
 # Complex type {http://schemas.xmlsoap.org/wsdl/mime/}tMimeXml with content type EMPTY
 class tMimeXml (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
+    """Complex type {http://schemas.xmlsoap.org/wsdl/mime/}tMimeXml with content type EMPTY"""
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tMimeXml')
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 65, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 65, 4)
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
     # Attribute part uses Python identifier part
     __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlmime_tMimeXml_part', pyxb.binding.datatypes.NMTOKEN)
-    __part._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 69, 3)
-    __part._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/mimebind.xsd', 69, 3)
+    __part._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 69, 3)
+    __part._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 69, 3)
     
     part = property(__part.value, __part.set, None, None)
 
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
 
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _ElementMap.update({
@@ -187,25 +189,63 @@ class tMimeXml (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
 Namespace.addCategoryObject('typeBinding', u'tMimeXml', tMimeXml)
 
 
-multipartRelated = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'multipartRelated'), multipartRelatedType)
-Namespace.addCategoryObject('elementBinding', multipartRelated.name().localName(), multipartRelated)
-
-content = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'content'), contentType)
+content = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'content'), contentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 38, 4))
 Namespace.addCategoryObject('elementBinding', content.name().localName(), content)
 
-mimeXml = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'mimeXml'), tMimeXml)
+multipartRelated = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'multipartRelated'), multipartRelatedType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 48, 4))
+Namespace.addCategoryObject('elementBinding', multipartRelated.name().localName(), multipartRelated)
+
+mimeXml = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'mimeXml'), tMimeXml, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 64, 4))
 Namespace.addCategoryObject('elementBinding', mimeXml.name().localName(), mimeXml)
 
 
-tPart._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_strict, namespace_constraint=set([u'http://schemas.xmlsoap.org/wsdl/mime/'])), min_occurs=0L, max_occurs=None)
-    )
-tPart._ContentModel = pyxb.binding.content.ParticleModel(tPart._GroupModel, min_occurs=1, max_occurs=1)
+
+multipartRelatedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'part'), tPart, scope=multipartRelatedType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10)))
+
+def _BuildAutomaton ():
+    # Remove this helper function from the namespace after it's invoked
+    global _BuildAutomaton
+    del _BuildAutomaton
+    import pyxb.utils.fac as fac
+
+    counters = set()
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10))
+    counters.add(cc_0)
+    states = []
+    final_update = set()
+    final_update.add(fac.UpdateInstruction(cc_0, False))
+    symbol = pyxb.binding.content.ElementUse(multipartRelatedType._UseForTag(pyxb.namespace.ExpandedName(None, u'part')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 53, 10))
+    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
+    states.append(st_0)
+    transitions = []
+    transitions.append(fac.Transition(st_0, [
+        fac.UpdateInstruction(cc_0, True) ]))
+    st_0._set_transitionSet(transitions)
+    return fac.Automaton(states, counters, True, containing_state=None)
+multipartRelatedType._Automaton = _BuildAutomaton()
 
 
 
-multipartRelatedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'part'), tPart, scope=multipartRelatedType))
-multipartRelatedType._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(multipartRelatedType._UseForTag(pyxb.namespace.ExpandedName(None, u'part')), min_occurs=0L, max_occurs=None)
-    )
-multipartRelatedType._ContentModel = pyxb.binding.content.ParticleModel(multipartRelatedType._GroupModel, min_occurs=1, max_occurs=1)
+
+def _BuildAutomaton_ ():
+    # Remove this helper function from the namespace after it's invoked
+    global _BuildAutomaton_
+    del _BuildAutomaton_
+    import pyxb.utils.fac as fac
+
+    counters = set()
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 60, 9))
+    counters.add(cc_0)
+    states = []
+    final_update = set()
+    final_update.add(fac.UpdateInstruction(cc_0, False))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_strict, namespace_constraint=set([u'http://schemas.xmlsoap.org/wsdl/mime/'])), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/mimebind.xsd', 60, 9))
+    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
+    states.append(st_0)
+    transitions = []
+    transitions.append(fac.Transition(st_0, [
+        fac.UpdateInstruction(cc_0, True) ]))
+    st_0._set_transitionSet(transitions)
+    return fac.Automaton(states, counters, True, containing_state=None)
+tPart._Automaton = _BuildAutomaton_()
+
