@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wsam.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:8412da32cb8f7a70943a9934e4bb13ceb5b27944
-# Generated 2012-11-01 15:13:37.431666 by PyXB version 1.1.5
+# Generated 2012-12-17 13:09:29.057916 by PyXB version 1.2.1
 # Namespace http://www.w3.org/2007/02/addressing/metadata
 
 import pyxb
@@ -13,7 +13,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9ecb6e28-2460-11e2-9a34-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:47fc30d2-487d-11e2-83e2-c8600024e903')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -57,22 +57,23 @@ def CreateFromDOM (node, default_namespace=None):
     @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
     if default_namespace is None:
         default_namespace = Namespace.fallbackNamespace()
-    return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
+    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)
 
 
 # Complex type {http://www.w3.org/2007/02/addressing/metadata}ServiceNameType with content type SIMPLE
 class ServiceNameType (pyxb.binding.basis.complexTypeDefinition):
+    """Complex type {http://www.w3.org/2007/02/addressing/metadata}ServiceNameType with content type SIMPLE"""
     _TypeDefinition = pyxb.binding.datatypes.QName
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'ServiceNameType')
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsam.xsd', 23, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 23, 4)
     # Base type is pyxb.binding.datatypes.QName
     
     # Attribute EndpointName uses Python identifier EndpointName
     __EndpointName = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'EndpointName'), 'EndpointName', '__httpwww_w3_org200702addressingmetadata_ServiceNameType_EndpointName', pyxb.binding.datatypes.NCName)
-    __EndpointName._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsam.xsd', 26, 16)
-    __EndpointName._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsam.xsd', 26, 16)
+    __EndpointName._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 26, 16)
+    __EndpointName._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 26, 16)
     
     EndpointName = property(__EndpointName.value, __EndpointName.set, None, None)
 
@@ -87,19 +88,38 @@ class ServiceNameType (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'ServiceNameType', ServiceNameType)
 
 
+# Complex type {http://www.w3.org/2007/02/addressing/metadata}AttributedQNameType with content type SIMPLE
+class AttributedQNameType (pyxb.binding.basis.complexTypeDefinition):
+    """Complex type {http://www.w3.org/2007/02/addressing/metadata}AttributedQNameType with content type SIMPLE"""
+    _TypeDefinition = pyxb.binding.datatypes.QName
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedQNameType')
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 33, 4)
+    # Base type is pyxb.binding.datatypes.QName
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2007/02/addressing/metadata'))
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+Namespace.addCategoryObject('typeBinding', u'AttributedQNameType', AttributedQNameType)
+
+
 # Complex type [anonymous] with content type ELEMENT_ONLY
 class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
+    """Complex type [anonymous] with content type ELEMENT_ONLY"""
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsam.xsd', 46, 8)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 46, 8)
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://www.w3.org/2006/07/ws-policy}Policy uses Python identifier Policy
-    __Policy = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy'), 'Policy', '__httpwww_w3_org200702addressingmetadata_CTD_ANON_httpwww_w3_org200607ws_policyPolicy', False)
-    __Policy._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2)
-    __Policy._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsam.xsd', 47, 12)
+    __Policy = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy'), 'Policy', '__httpwww_w3_org200702addressingmetadata_CTD_ANON_httpwww_w3_org200607ws_policyPolicy', False, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2), )
 
     
     Policy = property(__Policy.value, __Policy.set, None, None)
@@ -117,11 +137,12 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
 
 # Complex type [anonymous] with content type EMPTY
 class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
+    """Complex type [anonymous] with content type EMPTY"""
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsam.xsd', 61, 8)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 55, 8)
     # Base type is pyxb.binding.datatypes.anyType
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2007/02/addressing/metadata'))
 
@@ -134,32 +155,14 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
 
 
 
-# Complex type {http://www.w3.org/2007/02/addressing/metadata}AttributedQNameType with content type SIMPLE
-class AttributedQNameType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = pyxb.binding.datatypes.QName
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedQNameType')
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsam.xsd', 33, 4)
-    # Base type is pyxb.binding.datatypes.QName
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2007/02/addressing/metadata'))
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'AttributedQNameType', AttributedQNameType)
-
-
 # Complex type [anonymous] with content type EMPTY
 class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
+    """Complex type [anonymous] with content type EMPTY"""
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsam.xsd', 55, 8)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 61, 8)
     # Base type is pyxb.binding.datatypes.anyType
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2007/02/addressing/metadata'))
 
@@ -172,25 +175,39 @@ class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
 
 
 
-ServiceName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ServiceName'), ServiceNameType)
+ServiceName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ServiceName'), ServiceNameType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 22, 4))
 Namespace.addCategoryObject('elementBinding', ServiceName.name().localName(), ServiceName)
 
-Addressing = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Addressing'), CTD_ANON)
-Namespace.addCategoryObject('elementBinding', Addressing.name().localName(), Addressing)
-
-NonAnonymousResponses = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'NonAnonymousResponses'), CTD_ANON_)
-Namespace.addCategoryObject('elementBinding', NonAnonymousResponses.name().localName(), NonAnonymousResponses)
-
-InterfaceName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'InterfaceName'), AttributedQNameType)
+InterfaceName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'InterfaceName'), AttributedQNameType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 32, 4))
 Namespace.addCategoryObject('elementBinding', InterfaceName.name().localName(), InterfaceName)
 
-AnonymousResponses = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AnonymousResponses'), CTD_ANON_2)
+Addressing = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Addressing'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 45, 4))
+Namespace.addCategoryObject('elementBinding', Addressing.name().localName(), Addressing)
+
+AnonymousResponses = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AnonymousResponses'), CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 54, 4))
 Namespace.addCategoryObject('elementBinding', AnonymousResponses.name().localName(), AnonymousResponses)
 
+NonAnonymousResponses = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'NonAnonymousResponses'), CTD_ANON_2, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 60, 4))
+Namespace.addCategoryObject('elementBinding', NonAnonymousResponses.name().localName(), NonAnonymousResponses)
 
 
-CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy'), pyxb.bundles.wssplat.wsp200607.CTD_ANON_, scope=CTD_ANON))
-CTD_ANON._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy')), min_occurs=1, max_occurs=1)
-    )
-CTD_ANON._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel, min_occurs=1, max_occurs=1)
+
+CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy'), pyxb.bundles.wssplat.wsp200607.CTD_ANON_3, scope=CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2)))
+
+def _BuildAutomaton ():
+    # Remove this helper function from the namespace after it's invoked
+    global _BuildAutomaton
+    del _BuildAutomaton
+    import pyxb.utils.fac as fac
+
+    counters = set()
+    states = []
+    final_update = set()
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsam.xsd', 48, 16))
+    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
+    states.append(st_0)
+    transitions = []
+    st_0._set_transitionSet(transitions)
+    return fac.Automaton(states, counters, False, containing_state=None)
+CTD_ANON._Automaton = _BuildAutomaton()
+
