@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wsdli.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:9a7cf9fba316541758d5e40c615b77e27a9ce79d
-# Generated 2012-11-01 15:13:38.015768 by PyXB version 1.1.5
+# Generated 2012-12-17 13:09:29.666046 by PyXB version 1.2.1
 # Namespace http://www.w3.org/ns/wsdl-instance
 
 import pyxb
@@ -13,7 +13,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9f25fe38-2460-11e2-8ed2-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:485ae5dc-487d-11e2-aaf6-c8600024e903')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -56,7 +56,7 @@ def CreateFromDOM (node, default_namespace=None):
     @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
     if default_namespace is None:
         default_namespace = Namespace.fallbackNamespace()
-    return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
+    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)
 
 
 # List simple type: [anonymous]
@@ -66,7 +66,7 @@ class STD_ANON (pyxb.binding.basis.STD_list):
     """Simple type that is a list of pyxb.binding.datatypes.anyURI."""
 
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsdli.xsd', 30, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsdli.xsd', 30, 4)
     _Documentation = None
 
     _ItemType = pyxb.binding.datatypes.anyURI
