@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wsdlx.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:d3f38c6564399f72e3eae2480c2f719d9951bdaa
-# Generated 2012-11-01 15:13:38.187980 by PyXB version 1.1.5
+# Generated 2012-12-17 13:09:29.836976 by PyXB version 1.2.1
 # Namespace http://www.w3.org/ns/wsdl-extensions
 
 import pyxb
@@ -13,7 +13,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9f40317c-2460-11e2-8364-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:4874e64e-487d-11e2-afee-c8600024e903')
 
 # Import bindings for namespaces imported into schema
 
@@ -56,5 +56,5 @@ def CreateFromDOM (node, default_namespace=None):
     @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
     if default_namespace is None:
         default_namespace = Namespace.fallbackNamespace()
-    return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
+    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)
 
