@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wsoap.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:3a38467dbfe17f8bf02ac4151ad87deda2d076d0
-# Generated 2012-11-01 15:13:37.628994 by PyXB version 1.1.5
+# Generated 2012-12-17 13:09:29.263393 by PyXB version 1.2.1
 # Namespace http://www.w3.org/ns/wsdl/soap
 
 import pyxb
@@ -13,7 +13,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9ee7ac8c-2460-11e2-bf51-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:481911c0-487d-11e2-8724-c8600024e903')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -57,7 +57,7 @@ def CreateFromDOM (node, default_namespace=None):
     @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
     if default_namespace is None:
         default_namespace = Namespace.fallbackNamespace()
-    return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
+    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)
 
 
 # Atomic simple type: {http://www.w3.org/ns/wsdl/soap}TokenAny
@@ -66,7 +66,7 @@ class TokenAny (pyxb.binding.datatypes.token, pyxb.binding.basis.enumeration_mix
     """An atomic simple type."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'TokenAny')
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 55, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 55, 1)
     _Documentation = None
 TokenAny._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=TokenAny, enum_prefix=None)
 TokenAny.any = TokenAny._CF_enumeration.addEnumeration(unicode_value=u'#any', tag=u'any')
@@ -80,7 +80,7 @@ class STD_ANON (pyxb.binding.basis.STD_list):
     """Simple type that is a list of pyxb.binding.datatypes.QName."""
 
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 70, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 70, 2)
     _Documentation = None
 
     _ItemType = pyxb.binding.datatypes.QName
@@ -90,62 +90,63 @@ STD_ANON._InitializeFacetMap()
 # superclasses pyxb.binding.datatypes.anySimpleType
 class STD_ANON_ (pyxb.binding.basis.STD_union):
 
-    """Simple type that is a union of TokenAny, STD_ANON."""
+    """Simple type that is a union of pyxb.binding.datatypes.QName, TokenAny."""
 
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 68, 3)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 62, 3)
     _Documentation = None
 
-    _MemberTypes = ( TokenAny, STD_ANON, )
-STD_ANON_._CF_pattern = pyxb.binding.facets.CF_pattern()
+    _MemberTypes = ( pyxb.binding.datatypes.QName, TokenAny, )
 STD_ANON_._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_)
+STD_ANON_._CF_pattern = pyxb.binding.facets.CF_pattern()
 STD_ANON_.any = u'#any'                           # originally TokenAny.any
-STD_ANON_._InitializeFacetMap(STD_ANON_._CF_pattern,
-   STD_ANON_._CF_enumeration)
+STD_ANON_._InitializeFacetMap(STD_ANON_._CF_enumeration,
+   STD_ANON_._CF_pattern)
 
 # Union simple type: [anonymous]
 # superclasses pyxb.binding.datatypes.anySimpleType
 class STD_ANON_2 (pyxb.binding.basis.STD_union):
 
-    """Simple type that is a union of pyxb.binding.datatypes.QName, TokenAny."""
+    """Simple type that is a union of TokenAny, STD_ANON."""
 
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 62, 3)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 68, 3)
     _Documentation = None
 
-    _MemberTypes = ( pyxb.binding.datatypes.QName, TokenAny, )
-STD_ANON_2._CF_pattern = pyxb.binding.facets.CF_pattern()
+    _MemberTypes = ( TokenAny, STD_ANON, )
 STD_ANON_2._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_2)
+STD_ANON_2._CF_pattern = pyxb.binding.facets.CF_pattern()
 STD_ANON_2.any = u'#any'                          # originally TokenAny.any
-STD_ANON_2._InitializeFacetMap(STD_ANON_2._CF_pattern,
-   STD_ANON_2._CF_enumeration)
+STD_ANON_2._InitializeFacetMap(STD_ANON_2._CF_enumeration,
+   STD_ANON_2._CF_pattern)
 
 # Complex type [anonymous] with content type ELEMENT_ONLY
 class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
+    """Complex type [anonymous] with content type ELEMENT_ONLY"""
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 33, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 33, 2)
     # Base type is pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType
     
     # Element documentation ({http://www.w3.org/ns/wsdl}documentation) inherited from {http://www.w3.org/ns/wsdl}DocumentedType
     
-    # Attribute required uses Python identifier required
-    __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'required'), 'required', '__httpwww_w3_orgnswsdlsoap_CTD_ANON_required', pyxb.binding.datatypes.boolean)
-    __required._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 37, 5)
-    __required._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 37, 5)
-    
-    required = property(__required.value, __required.set, None, None)
-
-    
     # Attribute ref uses Python identifier ref
     __ref = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'ref'), 'ref', '__httpwww_w3_orgnswsdlsoap_CTD_ANON_ref', pyxb.binding.datatypes.anyURI, required=True)
-    __ref._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 36, 5)
-    __ref._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 36, 5)
+    __ref._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 36, 5)
+    __ref._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 36, 5)
     
     ref = property(__ref.value, __ref.set, None, None)
 
+    
+    # Attribute required uses Python identifier required
+    __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'required'), 'required', '__httpwww_w3_orgnswsdlsoap_CTD_ANON_required', pyxb.binding.datatypes.boolean)
+    __required._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 37, 5)
+    __required._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 37, 5)
+    
+    required = property(__required.value, __required.set, None, None)
+
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/wsdl'))
 
     _ElementMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._ElementMap.copy()
@@ -154,43 +155,44 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     })
     _AttributeMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._AttributeMap.copy()
     _AttributeMap.update({
-        __required.name() : __required,
-        __ref.name() : __ref
+        __ref.name() : __ref,
+        __required.name() : __required
     })
 
 
 
 # Complex type [anonymous] with content type ELEMENT_ONLY
 class CTD_ANON_ (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
+    """Complex type [anonymous] with content type ELEMENT_ONLY"""
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 44, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 44, 2)
     # Base type is pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType
     
     # Element documentation ({http://www.w3.org/ns/wsdl}documentation) inherited from {http://www.w3.org/ns/wsdl}DocumentedType
     
     # Attribute element uses Python identifier element
     __element = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'element'), 'element', '__httpwww_w3_orgnswsdlsoap_CTD_ANON__element', pyxb.binding.datatypes.QName, required=True)
-    __element._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 47, 5)
-    __element._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 47, 5)
+    __element._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 47, 5)
+    __element._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 47, 5)
     
     element = property(__element.value, __element.set, None, None)
 
     
     # Attribute mustUnderstand uses Python identifier mustUnderstand
     __mustUnderstand = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'mustUnderstand'), 'mustUnderstand', '__httpwww_w3_orgnswsdlsoap_CTD_ANON__mustUnderstand', pyxb.binding.datatypes.boolean)
-    __mustUnderstand._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 48, 5)
-    __mustUnderstand._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 48, 5)
+    __mustUnderstand._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 48, 5)
+    __mustUnderstand._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 48, 5)
     
     mustUnderstand = property(__mustUnderstand.value, __mustUnderstand.set, None, None)
 
     
     # Attribute required uses Python identifier required
     __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'required'), 'required', '__httpwww_w3_orgnswsdlsoap_CTD_ANON__required', pyxb.binding.datatypes.boolean)
-    __required._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 49, 5)
-    __required._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsoap.xsd', 49, 5)
+    __required._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 49, 5)
+    __required._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 49, 5)
     
     required = property(__required.value, __required.set, None, None)
 
@@ -209,20 +211,58 @@ class CTD_ANON_ (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
 
 
 
-module = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'module'), CTD_ANON)
+module = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'module'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 32, 1))
 Namespace.addCategoryObject('elementBinding', module.name().localName(), module)
 
-header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'header'), CTD_ANON_)
+header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'header'), CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsoap.xsd', 43, 1))
 Namespace.addCategoryObject('elementBinding', header.name().localName(), header)
 
 
-CTD_ANON._GroupModel_ = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/ns/wsdl'), u'documentation')), min_occurs=0L, max_occurs=None)
-    )
-CTD_ANON._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel_, min_occurs=1, max_occurs=1)
+
+def _BuildAutomaton ():
+    # Remove this helper function from the namespace after it's invoked
+    global _BuildAutomaton
+    del _BuildAutomaton
+    import pyxb.utils.fac as fac
+
+    counters = set()
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
+    counters.add(cc_0)
+    states = []
+    final_update = set()
+    final_update.add(fac.UpdateInstruction(cc_0, False))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/ns/wsdl'), u'documentation')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
+    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
+    states.append(st_0)
+    transitions = []
+    transitions.append(fac.Transition(st_0, [
+        fac.UpdateInstruction(cc_0, True) ]))
+    st_0._set_transitionSet(transitions)
+    return fac.Automaton(states, counters, True, containing_state=None)
+CTD_ANON._Automaton = _BuildAutomaton()
 
 
-CTD_ANON_._GroupModel_ = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/ns/wsdl'), u'documentation')), min_occurs=0L, max_occurs=None)
-    )
-CTD_ANON_._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_._GroupModel_, min_occurs=1, max_occurs=1)
+
+
+def _BuildAutomaton_ ():
+    # Remove this helper function from the namespace after it's invoked
+    global _BuildAutomaton_
+    del _BuildAutomaton_
+    import pyxb.utils.fac as fac
+
+    counters = set()
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
+    counters.add(cc_0)
+    states = []
+    final_update = set()
+    final_update.add(fac.UpdateInstruction(cc_0, False))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/ns/wsdl'), u'documentation')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
+    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
+    states.append(st_0)
+    transitions = []
+    transitions.append(fac.Transition(st_0, [
+        fac.UpdateInstruction(cc_0, True) ]))
+    st_0._set_transitionSet(transitions)
+    return fac.Automaton(states, counters, True, containing_state=None)
+CTD_ANON_._Automaton = _BuildAutomaton_()
+
