@@ -133,12 +133,12 @@ class ExpandedName (object):
 
         Expected argument patterns are:
 
-        ( C{str} ) -- the local name in an absent namespace
-        ( L{ExpandedName} ) -- a copy of the given expanded name
-        ( C{xml.dom.Node} ) -- The name extracted from node.namespaceURI and node.localName
-        ( C{str}, C{str} ) -- the namespace URI and the local name
-        ( L{Namespace}, C{str} ) -- the namespace and the local name
-        ( L{ExpandedName}, C{str}) -- the namespace from the expanded name, and the local name
+         - ( C{str} ) : the local name in an absent namespace
+         - ( L{ExpandedName} ) : a copy of the given expanded name
+         - ( C{xml.dom.Node} ) : The name extracted from node.namespaceURI and node.localName
+         - ( C{str}, C{str} ) : the namespace URI and the local name
+         - ( L{Namespace}, C{str} ) : the namespace and the local name
+         - ( L{ExpandedName}, C{str}) : the namespace from the expanded name, and the local name
 
         Wherever C{str} occurs C{unicode} is also permitted.
         
@@ -652,8 +652,7 @@ class Namespace (_NamespaceCategory_mixin, resolution._NamespaceResolution_mixin
         one (e.g., for a schema with no target namespace), don't lose hold of
         it."""
         assert uri is not None
-        return cls.__Registry.get(uri, None)
-
+        return cls.__Registry.get(uri)
 
     def __getnewargs__ (self):
         """Pickling support.
@@ -893,7 +892,7 @@ class Namespace (_NamespaceCategory_mixin, resolution._NamespaceResolution_mixin
                     _log.info('Load %s from %s', mr, mr.archive())
                     try:
                         mr.archive().readNamespaces()
-                    except pyxb.NamespaceArchiveError, e:
+                    except pyxb.NamespaceArchiveError as e:
                         _log.exception("Failure reading namespaces in archive")
                 else:
                     _log.info('Ignoring private module %s in validation', mr)
