@@ -54,6 +54,8 @@ def StringToDOM (text, **kw):
     @see: L{pyxb._SetXMLStyle}."""
     if pyxb.XMLStyle_minidom == pyxb._XMLStyle:
         parser = pyxb.utils.saxutils.make_parser()
+        if isinstance(text, unicode):
+            text = text.encode(pyxb._InputEncoding)
         return xml.dom.minidom.parseString(text, parser)
     return pyxb.utils.saxdom.parseString(text, **kw)
 
@@ -614,7 +616,7 @@ class BindingDOMSupport (object):
             return clone_node
         if node.COMMENT_NODE == node.nodeType:
             return docnode.createComment(node.data)
-        raise pyxb.IncompleteImplementationError('Unable to clone type %s DOM node %s' % (node.nodeType, node))
+        raise ValueError('DOM node not supported in clone', node)
 
     def cloneIntoImplementation (self, node):
         """Create a deep copy of the node in the target implementation.
@@ -643,6 +645,11 @@ class BindingDOMSupport (object):
             child = self.cloneIntoImplementation(child)
         return parent.appendChild(child)
 
+    def appendTextChild (self, text, parent):
+        """Add the text to the parent as a text node."""
+        return parent.appendChild(self.document().createTextNode(text))
+        
+
 ## Local Variables:
 ## fill-column:78
 ## End:
