@@ -96,11 +96,40 @@ class _NoopSAXHandler (xml.sax.handler.ContentHandler):
     def processingInstruction (self, target, data):
         pass
 
+class SAXInformationItem (object):
+    """Class used to capture an item discovered in the body of an element."""
+    
+    location = None
+    """Where the item began in the document."""
+
+    item = None
+    """The item.  Generally either character information (as text) or a DOM
+    Node instance or a binding instance."""
+    
+    maybe_element = None
+    """C{False} iff the L{item} is character information as opposed to element content."""
+
+    element_decl = None
+    """A reference to the
+    L{ElementDeclaration<pyxb.binding.content.ElementDeclaration>} used for
+    the L{item}.  This will be C{None} for element content that does not have
+    an enclosing CTD scope."""
+    
+    def __init__ (self, location, item, maybe_element, element_decl=None):
+        self.location = location
+        self.item = item
+        self.maybe_element = maybe_element
+        self.element_decl = element_decl
 
 class SAXElementState (object):
     """State corresponding to processing a given element with the SAX
     model."""
 
+    def contentHandler (self):
+        """Reference to the C{xml.sxa.handler.ContentHandler} that is processing the document."""
+        return self.__contentHandler
+    __contentHandler = None
+
     def parentState (self):
         """Reference to the SAXElementState of the element enclosing this
         one."""
@@ -132,36 +161,38 @@ class SAXElementState (object):
         This is a list, with each member being C{(content, element_use,
         maybe_element)}.  C{content} is text or a binding instance;
         C{element_use} is C{None} or the
-        L{ElementUse<pyxb.binding.content.ElementUse>} instance used to create
+        L{ElementDeclaration<pyxb.binding.content.ElementDeclaration>} instance used to create
         the content; and C{maybe_element} is C{True} iff the content is
         non-content text."""
         return self.__content
     __content = None
 
     def __init__ (self, **kw):
-        self.__expandedName = kw.get('expanded_name', None)
+        self.__expandedName = kw.get('expanded_name')
         self.__namespaceContext = kw['namespace_context']
-        self.__parentState = kw.get('parent_state', None)
-        self.__location = kw.get('location', None)
+        self.__parentState = kw.get('parent_state')
+        self.__contentHandler = kw.get('content_handler')
+        assert self.__contentHandler is not None
+        self.__location = self.__contentHandler.location()
         self.__content = []
 
-    def addTextContent (self, content):
+    def addTextContent (self, location, content):
         """Add the given text as non-element content of the current element.
         @type content: C{unicode} or C{str}
         @return: C{self}
         """
-        self.__content.append( (content, None, False) )
+        self.__content.append(SAXInformationItem(location, content, False))
 
-    def addElementContent (self, element, element_use):
-        """Add the given binding instance as element content correspondidng to
+    def addElementContent (self, location, element, element_decl=None):
+        """Add the given binding instance as element content corresponding to
         the given use.
 
         @param element: Any L{binding instance<pyxb.binding.basis._TypeBinding_mixin>}.
 
-        @param element_use: The L{element
-        use<pyxb.binding.content.ElementUse>} in the containing complex type.
+        @param element_decl: The L{element
+        use<pyxb.binding.content.ElementDeclaration>} in the containing complex type.
         """
-        self.__content.append( (element, element_use, True) )
+        self.__content.append(SAXInformationItem(location, element, True, element_decl))
 
 class BaseSAXHandler (xml.sax.handler.ContentHandler, object):
     """A SAX handler class that maintains a stack of enclosing elements and
@@ -175,6 +206,10 @@ class BaseSAXHandler (xml.sax.handler.ContentHandler, object):
     # construct the locations of events as they are received.
     __locationTemplate = None
 
+    def location (self):
+        """Return the current location within the SAX-processed document."""
+        return self.__locationTemplate.newLocation(self.__locator)
+
     # The callable that creates an instance of (a subclass of)
     # L{SAXElementState} as required to hold element-specific information as
     # parsing proceeds.
@@ -241,7 +276,8 @@ class BaseSAXHandler (xml.sax.handler.ContentHandler, object):
                                                                              including_context=self.__includingContext,
                                                                              finalize_target_namespace=False)
         self.__nextNamespaceContext = None
-        self.__elementState = self.__elementStateConstructor(namespace_context=self.__namespaceContext)
+        self.__elementState = self.__elementStateConstructor(content_handler=self,
+                                                             namespace_context=self.__namespaceContext)
         self.__elementStateStack = []
         self.__rootObject = None
         # Note: setDocumentLocator is invoked before startDocument (which
@@ -329,10 +365,10 @@ class BaseSAXHandler (xml.sax.handler.ContentHandler, object):
         # state for this element.
         parent_state = self.__elementState
         self.__elementStateStack.append(self.__elementState)
-        self.__elementState = this_state = self.__elementStateConstructor(expanded_name=expanded_name,
+        self.__elementState = this_state = self.__elementStateConstructor(content_handler=self,
+                                                                          expanded_name=expanded_name,
                                                                           namespace_context=ns_ctx,
-                                                                          parent_state=parent_state,
-                                                                          location=self.__locationTemplate.newLocation(self.__locator))
+                                                                          parent_state=parent_state)
         return (this_state, parent_state, ns_ctx, expanded_name)
 
     def endElementNS (self, name, qname):
@@ -354,13 +390,20 @@ class BaseSAXHandler (xml.sax.handler.ContentHandler, object):
     # to join them all at once, and to process one content value rather than a
     # sequence of them.
     __pendingText = None
+    __pendingTextLocation = None
     def __flushPendingText (self):
         if self.__pendingText:
-            self.__elementState.addTextContent(''.join(self.__pendingText))
+            location = self.__pendingTextLocation
+            if location is None:
+                location = self.location()
+            self.__elementState.addTextContent(location, ''.join(self.__pendingText))
+        self.__pendingTextLocation = None
         self.__pendingText = []
 
     def characters (self, content):
         """Save the text as content"""
+        if self.__pendingTextLocation is None:
+            self.__pendingTextLocation = self.location()
         self.__pendingText.append(content)
 
     def ignorableWhitespace (self, whitespace):
@@ -445,6 +488,7 @@ def make_parser (**kw):
 
 if '__main__' == __name__:
     import xml.dom.pulldom
+    import xml.dom.minidom
     import pyxb.utils.saxdom as saxdom
     import time
     import lxml.sax
