@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2009-2012, Peter A. Bigot
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -32,6 +33,9 @@ and refers to U{Unicode Standard Annex #27: Unicode 3.1
 """
 
 import re
+import logging
+
+_log = logging.getLogger(__name__)
 
 SupportsWideUnicode = False
 try:
@@ -89,8 +93,8 @@ class CodePointSet (object):
                 return
             if isinstance(args[0], list):
                 args = args[0]
-        [ self.add(_a) for _a in args ]
-
+        for a in args:
+            self.add(a)
 
     def __mutate (self, value, do_add):
         # Identify the start (inclusive) and end (exclusive) code
@@ -125,7 +129,6 @@ class CodePointSet (object):
         case = ((li & 1) << 1) | (ri & 1)
         if not do_add:
             case = 3 - case
-        #print 'add %d %d to %s at %d %d' % (s, e, self.__codepoints, li, ri)
         if 0x03 == case:
             # Add: Incoming value begins and ends within existing ranges
             del self.__codepoints[li:ri]
@@ -161,7 +164,8 @@ class CodePointSet (object):
         if isinstance(values, CodePointSet):
             self.extend(values.asTuples())
         else:
-            [ self.__mutate(_v, True) for _v in values ]
+            for v in values:
+                self.__mutate(v, True)
         return self
 
     def subtract (self, value):
@@ -173,20 +177,32 @@ class CodePointSet (object):
 
         @return: C{self}"""
         if isinstance(value, CodePointSet):
-            [ self.subtract(_v) for _v in value.asTuples() ]
+            for v in value.asTuples():
+                self.subtract(v)
             return self
         return self.__mutate(value, False)
 
-    # Characters that must not appear unescaped in regular expression
-    # patterns
-    __NotXMLChar_set = frozenset([ '-', '[', ']' ])
+    # Escape sequences for characters that must not appear unescaped in
+    # Python regular expression patterns.  Maps each bad character to a safe
+    # escape sequence.
+    __XMLtoPythonREMap = {
+        u'\x00': u'\\x00',  # From docs for Python's "re" module: Regular
+                            # expression pattern strings may not contain null
+                            # bytes
+        u'^': u'\\^',  # Indicates negation if it happens to occur at the
+                       # start of a character group
+        u'\\': u'\\\\',  # Escape character
+        u'[': u'\\[',  # Actually doesn't need to be escaped inside a Python
+                       # character group, but escaping it is less confusing.
+        u']': u'\\]',  # End of character group
+        u'-': u'\\-',  # Indicates a range of characters
+    }
 
     # Return the given code point as a unicode character suitable for
     # use in a regular expression
     def __unichr (self, code_point):
         rv = unichr(code_point)
-        if rv in self.__NotXMLChar_set:
-            rv = u'\\' + rv
+        rv = self.__XMLtoPythonREMap.get(rv, rv)
         return rv
 
     def asPattern (self, with_brackets=True):
@@ -194,6 +210,10 @@ class CodePointSet (object):
         character group consisting of a sequence of characters or
         character ranges.
 
+        This returns a regular expression fragment using Python's
+        regular expression syntax.  Note that different regular expression
+        syntaxes are not compatible, often in subtle ways.
+
         @param with_brackets: If C{True} (default), square brackets
         are added to enclose the returned character group."""
         rva = []
@@ -239,12 +259,13 @@ class CodePointSet (object):
     
     def asSingleCharacter (self):
         """If this set represents a single character, return it as its
-        unicode string value."""
+        unicode string value.  Otherwise return C{None}."""
         if (2 != len(self.__codepoints)) or (1 < (self.__codepoints[1] - self.__codepoints[0])):
-            raise CodePointSetError('CodePointSet does not represent single character')
+            return None
         return unichr(self.__codepoints[0])
 
-from unicode_data import *
+from pyxb.utils.unicode_data import PropertyMap
+from pyxb.utils.unicode_data import BlockMap
 
 class XML1p0e2 (object):
     """Regular expression support for XML Schema Data Types.
@@ -490,7 +511,7 @@ class XML1p0e2 (object):
         ( 0x3021, 0x3029 )
         )
 
-    Letter = CodePointSet(BaseChar).extend(Ideographic);
+    Letter = CodePointSet(BaseChar).extend(Ideographic)
 
     CombiningChar = CodePointSet(
         ( 0x0300, 0x0345 ),
@@ -663,6 +684,20 @@ SingleCharEsc = { 'n' : CodePointSet(0x0A),
 for c in r'\|.-^?*+{}()[]':
     SingleCharEsc[c] = CodePointSet(ord(c))
 
+# Production 25 : Category Escapes
+# Production 26: Complemented Category Escapes
+catEsc = { }
+complEsc = { }
+for k, v in PropertyMap.iteritems():
+    catEsc[u'p{%s}' % (k,)] = v
+    catEsc[u'P{%s}' % (k,)] = v.negate()
+
+# Production 36 : IsBlock escapes
+IsBlockEsc = { }
+for k, v in BlockMap.iteritems():
+    IsBlockEsc[u'p{Is%s}' % (k,)] = v
+    IsBlockEsc[u'P{Is%s}' % (k,)] = v.negate()
+
 # Production 37 : Multi-Character Escapes
 WildcardEsc = CodePointSet(ord('\n'), ord('\r')).negate()
 MultiCharEsc = { }
@@ -676,3 +711,4 @@ MultiCharEsc['d'] = PropertyMap['Nd']
 MultiCharEsc['D'] = MultiCharEsc['d'].negate()
 MultiCharEsc['W'] = CodePointSet(PropertyMap['P']).extend(PropertyMap['Z']).extend(PropertyMap['C'])
 MultiCharEsc['w'] = MultiCharEsc['W'].negate()
+
