@@ -133,6 +133,10 @@ keywords.
 
 _PythonBuiltInConstants = frozenset( (
         "False", "True", "None", "NotImplemented", "Ellipsis", "__debug__",
+        # "set" is neither a keyword nor a constant, but if some fool
+        # like {http://www.w3.org/2001/SMIL20/}set gets defined there's
+        # no way to access the builtin constructor.
+        "set"
         ) )
 """Other symbols that aren't keywords but that can't be used.
 
@@ -506,7 +510,7 @@ class Graph:
         @return: The SCC set, or C{None} if the node is not present in
         the results of Tarjan's algorithm."""
         
-        return self.sccMap(**kw).get(node, None)
+        return self.sccMap(**kw).get(node)
 
     def cyclomaticComplexity (self):
         """Return the cyclomatic complexity of the graph."""
@@ -561,6 +565,40 @@ class Graph:
                 raise Exception('DFS walk did not cover all nodes (walk %d versus nodes %d)' % (len(self.__dfsOrder), len(self.__nodes)))
         return self.__dfsOrder
         
+    def rootSetOrder (self):
+        """Return the nodes of the graph as a sequence of root sets.
+
+        The first root set is the set of nodes that are roots: i.e.,
+        have no incoming edges.  The second root set is the set of
+        nodes that have incoming nodes in the first root set.  This
+        continues until all nodes have been reached.  The sets impose
+        a partial order on the nodes, without being as constraining as
+        L{sccOrder}.
+
+        @return: a list of the root sets."""
+        order = []
+        nodes = set(self.__nodes)
+        edge_map = {}
+        for (d, srcs) in self.__edgeMap.iteritems():
+            edge_map[d] = srcs.copy()
+        while nodes:
+            freeset = set()
+            for n in nodes:
+                if not (n in edge_map):
+                    freeset.add(n)
+            if 0 == len(freeset):
+                _log.error('dependency cycle in named components')
+                return None
+            order.append(freeset)
+            nodes.difference_update(freeset)
+            new_edge_map = {}
+            for (d, srcs) in edge_map.iteritems():
+                srcs.difference_update(freeset)
+                if 0 != len(srcs):
+                    new_edge_map[d] = srcs
+            edge_map = new_edge_map
+        return order
+
 LocationPrefixRewriteMap_ = { }
 
 def SetLocationPrefixRewriteMap (prefix_map):
@@ -626,7 +664,7 @@ def TextFromURI (uri, archive_directory=None):
     if 0 <= uri.find(':'):
         try:
             stream = urllib2.urlopen(uri)
-        except Exception, e:
+        except Exception as e:
             exc = e
         if stream is None:
             try:
@@ -640,7 +678,7 @@ def TextFromURI (uri, archive_directory=None):
         try:
             stream = file(uri)
             exc = None
-        except Exception, e:
+        except Exception as e:
             if exc is None:
                 exc = e
     if exc is not None:
@@ -663,7 +701,7 @@ def TextFromURI (uri, archive_directory=None):
             counter += 1
         try:
             OpenOrCreate(dest_file).write(xmls)
-        except OSError, e:
+        except OSError as e:
             _log.warning('Unable to save %s in %s: %s', uri, dest_file, e)
     return xmls
 
@@ -693,7 +731,7 @@ def OpenOrCreate (file_name, tag=None, preserve_contents=False):
     if path:
         try:
             os.makedirs(path)
-        except Exception, e:
+        except Exception as e:
             if not (isinstance(e, (OSError, IOError)) and (errno.EEXIST == e.errno)):
                 raise
     fp = file(file_name, 'ab+')
@@ -1114,10 +1152,25 @@ class Location (object):
     lineNumber = property(lambda _s: _s.__lineNumber)
     columnNumber = property(lambda _s: _s.__columnNumber)
 
+    def __cmp__ (self, other):
+        """Comparison by locationBase, then lineNumber, then columnNumber."""
+        if other is None:
+            return 1
+        rv = cmp(self.__locationBase, other.__locationBase)
+        if 0 == rv:
+            rv = cmp(self.__lineNumber, other.__lineNumber)
+        if 0 == rv:
+            rv = cmp(self.__columnNumber, other.__columnNumber)
+        return rv
+
     def __str__ (self):
         if self.locationBase is None:
-            return '<unknownLocation>'
-        return '%s[%s:%s]' % (self.locationBase, self.lineNumber, self.columnNumber)
+            lb = '<unknown>'
+        else:
+            # No, this should not be os.sep.  The location is
+            # expected to be a URI.
+            lb = self.locationBase.rsplit('/', 1)[-1]
+        return '%s[%s:%s]' % (lb, self.lineNumber, self.columnNumber)
 
     def __repr__ (self):
         t = type(self)
