@@ -47,7 +47,7 @@ class Test_duration (unittest.TestCase):
         self.assertFalse(v.negativeDuration())
         self.assertEqual('P1347M', v.xsdLiteral())
 
-        self.assertRaises(pyxb.BadTypeValueError, xsd.duration, 'P-1347M')
+        self.assertRaises(pyxb.SimpleTypeValueError, xsd.duration, 'P-1347M')
         v = xsd.duration('-P1347M')
         self.assertEqual(0, v.days)
         self.assertEqual(0, v.seconds)
@@ -56,7 +56,7 @@ class Test_duration (unittest.TestCase):
         self.assertTrue(v.negativeDuration())
         self.assertEqual('-P1347M', v.xsdLiteral())
 
-        self.assertRaises(pyxb.BadTypeValueError, xsd.duration, 'P1Y2MT')
+        self.assertRaises(pyxb.SimpleTypeValueError, xsd.duration, 'P1Y2MT')
 
         v = xsd.duration('P3DT4H7M')
 
@@ -102,8 +102,8 @@ class Test_duration (unittest.TestCase):
         self.assertEqual(3, v.days)
         self.assertEqual(14842, v.seconds)
         self.assertEqual('P3DT4H7M22.5S', v.xsdLiteral())
-        self.assertRaises(pyxb.BadTypeValueError, xsd.duration)
-        self.assertRaises(pyxb.BadTypeValueError, xsd.duration, 4)
+        self.assertRaises(pyxb.SimpleTypeValueError, xsd.duration)
+        self.assertRaises(pyxb.SimpleTypeValueError, xsd.duration, 4)
 
 if __name__ == '__main__':
     unittest.main()
