@@ -20,10 +20,10 @@ class Test_time (unittest.TestCase):
         self.assertEqual(with_tzinfo, tm.tzinfo is not None)
 
     def testBad (self):
-        self.assertRaises(pyxb.BadTypeValueError, xsd.time, '12: 14: 32')
-        self.assertRaises(pyxb.BadTypeValueError, xsd.time, '12:14:32.Z')
-        self.assertRaises(pyxb.BadTypeValueError, xsd.time, '12:14:32.123405:00')
-        self.assertRaises(pyxb.BadTypeValueError, xsd.time, '12:14:32.1234+05')
+        self.assertRaises(pyxb.SimpleTypeValueError, xsd.time, '12: 14: 32')
+        self.assertRaises(pyxb.SimpleTypeValueError, xsd.time, '12:14:32.Z')
+        self.assertRaises(pyxb.SimpleTypeValueError, xsd.time, '12:14:32.123405:00')
+        self.assertRaises(pyxb.SimpleTypeValueError, xsd.time, '12:14:32.1234+05')
         
     def testFromText (self):
         self.verifyTime(xsd.time('12:14:32'), with_usec=False, with_tzinfo=False)
