@@ -24,18 +24,18 @@ import unittest
 
 class TestEnumerations (unittest.TestCase):
     def testString (self):
-        self.assertRaises(pyxb.BadTypeValueError, eString, 'fourteen')
-        self.assertRaises(pyxb.BadTypeValueError, CreateFromDocument, '<eString>fourteen</eString>')
+        self.assertRaises(pyxb.SimpleTypeValueError, eString, 'fourteen')
+        self.assertRaises(pyxb.SimpleTypeValueError, CreateFromDocument, '<eString>fourteen</eString>')
         self.assertEqual('one', eString('one'))
         self.assertEqual('one', CreateFromDocument('<eString>one</eString>'))
         self.assertEqual(eString.typeDefinition().one, 'one')
 
     def testInteger (self):
         self.assertTrue(issubclass(tInteger, xs.int))
-        self.assertRaises(pyxb.BadTypeValueError, eInteger, 4)
-        self.assertRaises(pyxb.BadTypeValueError, eInteger, '4')
-        self.assertRaises(pyxb.BadTypeValueError, CreateFromDocument, '<eInteger>4</eInteger>')
-        self.assertRaises(pyxb.BadTypeValueError, eInteger) # Value defaults to zero, not in enumeration
+        self.assertRaises(pyxb.SimpleTypeValueError, eInteger, 4)
+        self.assertRaises(pyxb.SimpleTypeValueError, eInteger, '4')
+        self.assertRaises(pyxb.SimpleTypeValueError, CreateFromDocument, '<eInteger>4</eInteger>')
+        self.assertRaises(pyxb.SimpleTypeValueError, eInteger) # Value defaults to zero, not in enumeration
         self.assertEqual(3, eInteger(3))
         self.assertEqual(3, CreateFromDocument('<eInteger>3</eInteger>'))
         self.assertEqual(21, eInteger(21))
@@ -43,13 +43,13 @@ class TestEnumerations (unittest.TestCase):
 
     def testDouble (self):
         self.assertTrue(issubclass(tDouble, xs.double))
-        self.assertRaises(pyxb.BadTypeValueError, eDouble, 2)
-        self.assertRaises(pyxb.BadTypeValueError, eDouble, 2.0)
-        self.assertRaises(pyxb.BadTypeValueError, eDouble, '2')
-        self.assertRaises(pyxb.BadTypeValueError, eDouble, '2.0')
-        self.assertRaises(pyxb.BadTypeValueError, CreateFromDocument, '<eDouble>2</eDouble>')
-        self.assertRaises(pyxb.BadTypeValueError, CreateFromDocument, '<eDouble>2.0</eDouble>')
-        self.assertRaises(pyxb.BadTypeValueError, eDouble) # Value defaults to zero, not in enumeration
+        self.assertRaises(pyxb.SimpleTypeValueError, eDouble, 2)
+        self.assertRaises(pyxb.SimpleTypeValueError, eDouble, 2.0)
+        self.assertRaises(pyxb.SimpleTypeValueError, eDouble, '2')
+        self.assertRaises(pyxb.SimpleTypeValueError, eDouble, '2.0')
+        self.assertRaises(pyxb.SimpleTypeValueError, CreateFromDocument, '<eDouble>2</eDouble>')
+        self.assertRaises(pyxb.SimpleTypeValueError, CreateFromDocument, '<eDouble>2.0</eDouble>')
+        self.assertRaises(pyxb.SimpleTypeValueError, eDouble) # Value defaults to zero, not in enumeration
         self.assertEqual(1.0, eDouble(1.0))
         self.assertEqual(1.0, CreateFromDocument('<eDouble>1</eDouble>'))
         self.assertEqual(1.0, CreateFromDocument('<eDouble>1.0</eDouble>'))
@@ -60,9 +60,9 @@ class TestEnumerations (unittest.TestCase):
 
     def testAny (self):
         self.assertTrue(issubclass(tAny, xs.string))
-        self.assertRaises(pyxb.BadTypeValueError, eAny, 2)
-        self.assertRaises(pyxb.BadTypeValueError, eAny, '2')
-        self.assertRaises(pyxb.BadTypeValueError, CreateFromDocument, '<eAny>2</eAny>')
+        self.assertRaises(pyxb.SimpleTypeValueError, eAny, 2)
+        self.assertRaises(pyxb.SimpleTypeValueError, eAny, '2')
+        self.assertRaises(pyxb.SimpleTypeValueError, CreateFromDocument, '<eAny>2</eAny>')
         self.assertEqual('one', eAny('one'))
         self.assertEqual('one', CreateFromDocument('<eAny>one</eAny>'))
         self.assertEqual(eAny.typeDefinition().one, eAny('one'))
@@ -79,13 +79,13 @@ class TestEnumerations (unittest.TestCase):
         # NB Constraining value space, not lexical space, so whiteSpace facets apply
         self.assertEqual([1, 1, 2, 3], eListInt('1   1      2 3'))
         self.assertEqual([1, 1, 2, 3], CreateFromDocument('<eListInt>1    1       2 3</eListInt>'))
-        self.assertRaises(pyxb.BadTypeValueError, eListInt, '1 2 3')
-        self.assertRaises(pyxb.BadTypeValueError, eListInt, (1,2,3))
+        self.assertRaises(pyxb.SimpleTypeValueError, eListInt, '1 2 3')
+        self.assertRaises(pyxb.SimpleTypeValueError, eListInt, (1,2,3))
 
     def testListRestriction (self):
         self.assertTrue(9, len(justList([2] * 9)))
         self.assertTrue(10, len(justList([2] * 10)))
-        self.assertRaises(pyxb.BadTypeValueError, justList, [2] * 11)
+        self.assertRaises(pyxb.SimpleTypeValueError, justList, [2] * 11)
 
     def testJustUnion (self):
         self.assertEqual(uVarious.one, eJustVarious('one'))
@@ -95,11 +95,11 @@ class TestEnumerations (unittest.TestCase):
         self.assertEqual(1.0, v)
         self.assertEqual([1,1,2,3,5,8], eJustVarious((1,1,2,3,5,8)))
         self.assertEqual([1,1,2,3,5,8], CreateFromDocument('<eJustVarious>1 1 2 3 5 8</eJustVarious>'))
-        self.assertRaises(pyxb.BadTypeValueError, eJustVarious, (1,2,3,5,8))
+        self.assertRaises(pyxb.SimpleTypeValueError, eJustVarious, (1,2,3,5,8))
 
     def testUnion (self):
         self.assertEqual(tVarious.one, eVarious('one'))
-        self.assertRaises(pyxb.BadTypeValueError, eVarious, 'two')
+        self.assertRaises(pyxb.SimpleTypeValueError, eVarious, 'two')
         self.assertEqual(1.0, eVarious(1.0))
         self.assertEqual(1.0, eVarious('1.0'))
         v = eVarious('1')
@@ -109,9 +109,9 @@ class TestEnumerations (unittest.TestCase):
         v = eVarious(1)
         self.assertTrue(isinstance(v, float))
         self.assertEqual(1.0, eVarious('1')) # this is a valid float as well as int
-        self.assertRaises(pyxb.BadTypeValueError, eVarious, '1.6')
+        self.assertRaises(pyxb.SimpleTypeValueError, eVarious, '1.6')
         self.assertEqual([1,1,2,3], eVarious((1,1,2,3)))
-        self.assertRaises(pyxb.BadTypeValueError, eVarious, (1,1,2,3,5,8))
+        self.assertRaises(pyxb.SimpleTypeValueError, eVarious, (1,1,2,3,5,8))
 
 
 if __name__ == '__main__':
