@@ -6,6 +6,7 @@ _log = logging.getLogger(__name__)
 import pyxb.binding.generate
 import pyxb.utils.domutils
 from xml.dom import Node
+import sys
 
 import os.path
 schema_path = os.path.abspath(os.path.join(os.path.dirname(__file__), '../schemas/test-mg-all.xsd'))
@@ -25,7 +26,7 @@ class TestMGAll (unittest.TestCase):
     def testRequired (self):
         xml = '<ns1:required xmlns:ns1="URN:test-mg-all"/>'
         dom = pyxb.utils.domutils.StringToDOM(xml)
-        self.assertRaises(MissingContentError, required.createFromDOM, dom.documentElement)
+        self.assertRaises(IncompleteElementContentError, required.createFromDOM, dom.documentElement)
 
         xml = '<ns1:required xmlns:ns1="URN:test-mg-all"><first/><second/><third/></ns1:required>'
         dom = pyxb.utils.domutils.StringToDOM(xml)
@@ -45,7 +46,7 @@ class TestMGAll (unittest.TestCase):
     def testRequiredTooMany (self):
         xml = '<ns1:required xmlns:ns1="URN:test-mg-all"><third/><first/><second/><third/></ns1:required>'
         dom = pyxb.utils.domutils.StringToDOM(xml)
-        self.assertRaises(ExtraContentError, required.createFromDOM, dom.documentElement)
+        self.assertRaises(UnrecognizedContentError, required.createFromDOM, dom.documentElement)
 
     def testThirdOptional (self):
         xml = '<ns1:thirdOptional xmlns:ns1="URN:test-mg-all"><first/><second/></ns1:thirdOptional>'
@@ -64,7 +65,7 @@ class TestMGAll (unittest.TestCase):
 
         xml = '<ns1:thirdOptional xmlns:ns1="URN:test-mg-all"><first/><second/><third/><first/></ns1:thirdOptional>'
         dom = pyxb.utils.domutils.StringToDOM(xml)
-        self.assertRaises(ExtraContentError, thirdOptional.Factory, _dom_node=dom.documentElement)
+        self.assertRaises(UnrecognizedContentError, thirdOptional.Factory, _dom_node=dom.documentElement)
 
     def testOptional (self):
         xml = '<ns1:optional xmlns:ns1="URN:test-mg-all"/>'
@@ -98,7 +99,7 @@ class TestMGAll (unittest.TestCase):
     def testOptionalTooMany (self):
         xml = '<ns1:optional xmlns:ns1="URN:test-mg-all"><third/><first/><third/></ns1:optional>'
         dom = pyxb.utils.domutils.StringToDOM(xml)
-        self.assertRaises(ExtraContentError, optional.createFromDOM, dom.documentElement)
+        self.assertRaises(UnrecognizedContentError, optional.createFromDOM, dom.documentElement)
 
     def stripMembers (self, xml, body):
         for b in body:
@@ -122,8 +123,14 @@ class TestMGAll (unittest.TestCase):
         many_g = many.memberElement('g')
         many_h = many.memberElement('h')
         instance = many(a=many_a(), c=many_c(), d=many_d(), e=many_e(), f=many_f(), g=many_g(), h=many_h())
-        self.assertRaises(pyxb.BindingValidationError, instance.validateBinding)
-        self.assertRaises(pyxb.DOMGenerationError, ToDOM, instance)
+        self.assertRaises(pyxb.IncompleteElementContentError, instance.validateBinding)
+        self.assertRaises(pyxb.IncompleteElementContentError, ToDOM, instance)
+        if sys.version_info[:2] >= (2, 7):
+            with self.assertRaises(IncompleteElementContentError) as cm:
+                instance.validateBinding()
+            acceptable = cm.exception.fac_configuration.acceptableSymbols()
+            self.assertEqual(1, len(acceptable))
+            self.assertEqual(many.memberElement('b'), acceptable[0].elementDeclaration().elementBinding())
 
 if __name__ == '__main__':
     unittest.main()
