@@ -18,8 +18,8 @@ import unittest
 class TestKML (unittest.TestCase):
     def testAngle360 (self):
         self.assertEqual(25.4, angle360(25.4))
-        self.assertRaises(BadTypeValueError, angle360, 420.0)
-        self.assertRaises(BadTypeValueError, angle360, -361.0)
+        self.assertRaises(SimpleTypeValueError, angle360, 420.0)
+        self.assertRaises(SimpleTypeValueError, angle360, -361.0)
         
 if __name__ == '__main__':
     unittest.main()
