@@ -81,11 +81,14 @@ class TestTrac0039 (unittest.TestCase):
     """Creating nested anonymous elements"""
     def testShallowSet (self):
         w = shallow()
-        self.assertRaises(pyxb.BadTypeValueError, SET_optional, w, 5)
+        w.optional = 4
+        self.assertEqual(w.optional.value(), 4)
+        self.assertTrue(w.optional.deep is None)
         w.optional = BIND(5)
+        self.assertEqual(w.optional.value(), 5)
         self.assertTrue(w.optional.deep is None)
         self.assertTrue(isinstance(w.optional.value(), xs.int))
-        self.assertRaises(pyxb.BadTypeValueError, SET_optional, w, BIND('string'))
+        self.assertRaises(pyxb.SimpleTypeValueError, SET_optional, w, BIND('string'))
         w.optional = BIND(6, deep=1)
         self.assertEqual(w.optional.value(), 6)
         self.assertEqual(w.optional.deep, 1)
@@ -93,8 +96,11 @@ class TestTrac0039 (unittest.TestCase):
     def testShallowCTOR (self):
         w = shallow(BIND(5))
         self.assertTrue(isinstance(w.optional.value(), xs.int))
-        self.assertRaises(pyxb.UnexpectedNonElementContentError, shallow, 5)
-        self.assertRaises(pyxb.UnexpectedNonElementContentError, shallow, BIND('string'))
+        self.assertEqual(w.optional.value(), 5)
+        w = shallow(6)
+        self.assertTrue(isinstance(w.optional.value(), xs.int))
+        self.assertEqual(w.optional.value(), 6)
+        self.assertRaises(pyxb.UnrecognizedContentError, shallow, BIND('string'))
 
     def testDeep (self):
         w = wrapper(BIND(BIND(4, deep=4), BIND('hi')))
